part2

Function part2 

pub fn part2(input: &Vec<Vec<usize>>) -> u64
Split the route into 3 segments. The answer is the number of paths in each segment multiplied by each other. Since the input is a directed acyclic graph (DAG), only one of these paths will be possible.